@@ -21,17 +21,12 @@
 
 # this can go when things are a little further along
 try:
-    import ltihooks
-    del ltihooks
+    import ltihooks, sys
+    sys.path.insert(1, 'gobject')
+    del ltihooks, sys
 except ImportError:
     pass
 
-# TRUE and FALSE constants ...
-import __builtin__
-if not hasattr(__builtin__, 'True'):
-    __builtin__.True = (1 == 1)
-    __builtin__.False = (1 != 1)
-del __builtin__
 
 FALSE = False
 TRUE  = True
@@ -58,9 +53,19 @@ gdk.INPUT_READ      = _gobject.IO_IN | _gobject.IO_HUP | _gobject.IO_ERR
 gdk.INPUT_WRITE     = _gobject.IO_OUT | _gobject.IO_HUP
 gdk.INPUT_EXCEPTION = _gobject.IO_PRI
 
-del _gobject
+# _gobject deprecation
+from types import ModuleType as _module
+class _GObjectWrapper(_module):
+    from warnings import warn
+    warn = staticmethod(warn)
+    _gobject = _gobject
+    def __getattr__(self, attr):
+        self.warn('gtk._gobject is deprecated, use gobject directly instead')
+        return getattr(self._gobject, attr)
+_gobject = _GObjectWrapper('gtk._gobject')
+del _GObjectWrapper, _module
 
-# Warnings
+# other deprecated symbols
 class _Deprecated:
     from warnings import warn
     warn = staticmethod(warn)
@@ -74,7 +79,7 @@ class _Deprecated:
             self.module = 'gtk'
             
     def __repr__(self):
-        return '<deprecated function %s at 0x%x>' % (self.oldname, id(self))
+        return '<deprecated function %s>' % (self.oldname)
     
     def __call__(self, *args, **kwargs):
         message = 'gtk.%s is deprecated, use %s.%s instead' % (self.oldname,
@@ -96,4 +101,5 @@ create_pixmap_from_xpm = _Deprecated(gdk.pixmap_create_from_xpm,
                                      'pixmap_create_from_xpm', 'gdk')
 create_pixmap_from_xpm_d = _Deprecated(gdk.pixmap_create_from_xpm_d,
                                        'pixmap_create_from_xpm_d', 'gdk')
+
 del _Deprecated
