@@ -83,24 +83,29 @@ _pygtk_log_func(const gchar *log_domain,
                 const gchar *message,
                 gpointer user_data)
 {
+    PyGILState_STATE state;
+
+    state = pyg_gil_state_ensure();
     PyErr_Warn(PyGtkWarning, (char *) message);
+    pyg_gil_state_release(state);
 }
 
 static gboolean
 python_do_pending_calls(gpointer data)
 {
     gboolean quit = FALSE;
+    PyGILState_STATE state;
+
+    state = pyg_gil_state_ensure();
 
-    pyg_block_threads();
     if (PyErr_CheckSignals() == -1) {
 	PyErr_SetNone(PyExc_KeyboardInterrupt);
 	quit = TRUE;
     }
-    pyg_unblock_threads();
-
     if (quit && gtk_main_level() > 0)
 	gtk_main_quit();
     
+    pyg_gil_state_release(state);
     return TRUE;
 }
 
@@ -228,7 +233,7 @@ init_gtk(void)
     pygdk_register_classes(d);
     pygdk_add_constants(m, "GDK_");
       /* Add predefined atoms */
-#define add_atom(name) PyModule_AddObject(m, #name, PyGdkAtom_New(GDK_##name))
+#define add_atom(name) PyModule_AddObject(m, #name, PyString_FromString(gdk_atom_name((GDK_##name))))
 
     add_atom(SELECTION_PRIMARY);
     add_atom(SELECTION_SECONDARY);
